#!/bin/bash
#
# Launches sofa application with or without version specification. If the
# version is not specified as second argument, the script will look up
# the repository for list of versions. Then, if there is more than one
# option, it will ask user for selecting the version.
#

# Print message and exit (with error value 1).
fail() #MSG [OPT_MSG]
{
  echo "Failure: $1" >&2
  [ -z "$2" ] || echo "$2" >&2
  exit 1
}

log() #MSG
{
  echo "$0: $1"
}


if [ $# -lt 1 ]; then
  fail "Bad parameters." "  Usage: $0 name-of-app [version-of-app]" >&2
fi

version=$2

if [ -z "${version}" ]
then
  # Store versions into temporary file.
  cushion.sh print version "$1" | grep "^$1?version=.*$" | sed "s/^$1?version=\(.*\)$/\1/" > .cushion.$$.launch.versions

  is_longer=`tail -n +2 .cushion.$$.launch.versions | head -n 1`

  if [ -z "${is_longer}" ]
  then
    # Just one option...
    version=`head -n 1 .cushion.$$.launch.versions`
    rm -f .cushion.$$.launch.versions
  else
    # Many options...print them out and ask user
    echo "There are many versions avalable in the repository."
    index=1
    cat .cushion.$$.launch.versions | while read curr_vers
    do
      echo "[${index}] ${curr_vers}"
      index=`expr "${index}" + 1`
    done
    rm -f .cushion.$$.launch.versions
    echo -n "Pick a version from the list: "
    read index
    [ "${index}" -ge 0 ] >/dev/null 2>&1 || fail "Given bad number."
    version=`tail -n +${index} .cushion.$$.launch.versions | head -n 1`
    [ -n "${version}" ] || fail "Given too large number."
  fi

  # $version is empty or contains version
  [ -n "${version}" ] || fail "Unable to find entity $1."
fi

log "executing 'sofa-launch $1 -v ${version}'"

sofa-launch.sh "$1" -v "${version}"

